@@ -199,6 +199,9 @@ def construct_post_view_function(
         dict_struct=None, schemas_registry=None,
         fields_allowed_to_be_set=None,
         fields_forbidden_from_being_set=None, exception_handler=None,
+        remove_relationship_keys_before_validation=False,
+        remove_assoc_proxy_keys_before_validation=False,
+        remove_property_keys_before_validation=False,
         access_checker=None):
 
     def post():
@@ -222,8 +225,18 @@ def construct_post_view_function(
 
             fields_to_be_removed = union([
                 fields_forbidden_from_being_set or [],
-                model_class._fields_forbidden_from_being_set_ or [],
-                model_class.property_keys() or []])
+                model_class._fields_forbidden_from_being_set_ or []
+            ])
+            if remove_property_keys_before_validation:
+                fields_to_be_removed = union([
+                    fields_to_be_removed, model_class.property_keys() or []
+                ])
+            if remove_relationship_keys_before_validation:
+                fields_to_be_removed = union(
+                    [fields_to_be_removed, model_class.relationship_keys() or []])
+            if remove_assoc_proxy_keys_before_validation:
+                fields_to_be_removed = union(
+                    [fields_to_be_removed, model_class.association_proxy_keys() or []])
             if isinstance(input_data, list):
                 if fields_allowed_to_be_set and len(fields_to_be_removed) > 0:
                     for dict_item in input_data:
@@ -342,7 +355,10 @@ def construct_put_view_function(
         allow_unknown_fields=False,
         access_checker=None,
         fields_allowed_to_be_set=None,
-        fields_forbidden_from_being_set=None, exception_handler=None):
+        fields_forbidden_from_being_set=None, remove_relationship_keys_before_validation=False,
+        remove_assoc_proxy_keys_before_validation=False,
+        remove_property_keys_before_validation=False,
+        exception_handler=None):
     def put(_id):
         try:
             if permitted_object_getter is not None:
@@ -375,8 +391,18 @@ def construct_put_view_function(
 
             fields_to_be_removed = union([
                 fields_forbidden_from_being_set or [],
-                model_class._fields_forbidden_from_being_set_ or [],
-                model_class.property_keys() or []])
+                model_class._fields_forbidden_from_being_set_ or []
+            ])
+            if remove_property_keys_before_validation:
+                fields_to_be_removed = union([
+                    fields_to_be_removed, model_class.property_keys() or []
+                ])
+            if remove_relationship_keys_before_validation:
+                fields_to_be_removed = union(
+                    [fields_to_be_removed, model_class.relationship_keys() or []])
+            if remove_assoc_proxy_keys_before_validation:
+                fields_to_be_removed = union(
+                    [fields_to_be_removed, model_class.association_proxy_keys() or []])
             if len(fields_to_be_removed) > 0:
                 delete_dict_keys(input_data, fields_to_be_removed)
             input_data = model_class.pre_validation_adapter(input_data, existing_instance=obj)
@@ -686,8 +712,8 @@ def construct_batch_save_view_function(
 
         fields_to_be_removed = union([
             fields_forbidden_from_being_set or [],
-            model_class._fields_forbidden_from_being_set_ or [],
-            model_class.property_keys() or []])
+            model_class._fields_forbidden_from_being_set_ or []
+        ])
         if len(fields_to_be_removed) > 0:
             for dict_item in input_data:
                 delete_dict_keys(dict_item, fields_to_be_removed)
@@ -922,6 +948,12 @@ def register_crud_routes_for_models(
         dict_struct_for_model = _model_dict.get('dict_struct')
         fields_forbidden_from_being_set_for_all_views = _model_dict.get(
             'fields_forbidden_from_being_set', [])
+        fields_allowed_to_be_set_for_all_views = _model_dict.get(
+            'fields_allowed_to_be_set', [])
+        remove_relationship_keys_before_validation = _model_dict.get('remove_relationship_keys_before_validation', False)
+        remove_assoc_proxy_keys_before_validation = _model_dict.get('remove_assoc_proxy_keys_before_validation', False)
+        remove_property_keys_before_validation = _model_dict.get(
+            'remove_property_keys_before_validation', False)
         enable_caching = _model_dict.get(
             'enable_caching', False) and cache_handler is not None
         cache_timeout = _model_dict.get('cache_timeout')
@@ -1033,6 +1065,17 @@ def register_crud_routes_for_models(
                     'exception_handler') or default_exception_handler,
                 access_checker=post_dict.get(
                     'access_checker') or default_access_checker,
+                remove_property_keys_before_validation=post_dict.get(
+                    'remove_property_keys_before_validation') if post_dict.get(
+                    'remove_property_keys_before_validation') is not None else remove_property_keys_before_validation,
+                remove_relationship_keys_before_validation=post_dict.get(
+                    'remove_relationship_keys_before_validation') if post_dict.get(
+                    'remove_relationship_keys_before_validation') is not None else remove_relationship_keys_before_validation,
+                remove_assoc_proxy_keys_before_validation=post_dict.get(
+                    'remove_assoc_proxy_keys_before_validation') if post_dict.get(
+                    'remove_assoc_proxy_keys_before_validation') is not None else remove_assoc_proxy_keys_before_validation,
+                fields_allowed_to_be_set=post_dict.get(
+                    'fields_allowed_to_be_set') or fields_allowed_to_be_set_for_all_views,
                 fields_forbidden_from_being_set=union([
                     fields_forbidden_from_being_set_for_all_views,
                     post_dict.get('fields_forbidden_from_being_set', [])]))
@@ -1069,6 +1112,17 @@ def register_crud_routes_for_models(
                     'exception_handler') or default_exception_handler,
                 access_checker=put_dict.get(
                     'access_checker') or default_access_checker,
+                remove_property_keys_before_validation=post_dict.get(
+                    'remove_property_keys_before_validation') if post_dict.get(
+                    'remove_property_keys_before_validation') is not None else remove_property_keys_before_validation,
+                remove_relationship_keys_before_validation=put_dict.get(
+                    'remove_relationship_keys_before_validation') if put_dict.get(
+                    'remove_relationship_keys_before_validation') is not None else remove_relationship_keys_before_validation,
+                remove_assoc_proxy_keys_before_validation=put_dict.get(
+                    'remove_assoc_proxy_keys_before_validation') if put_dict.get(
+                    'remove_assoc_proxy_keys_before_validation') is not None else remove_assoc_proxy_keys_before_validation,
+                fields_allowed_to_be_set=put_dict.get(
+                    'fields_allowed_to_be_set') or fields_allowed_to_be_set_for_all_views,
                 fields_forbidden_from_being_set=union([
                     fields_forbidden_from_being_set_for_all_views,
                     put_dict.get('fields_forbidden_from_being_set', [])]))
